==> nextcloud-app-calendar-1%3A2.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ko.js <==
OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "사용자 세션이 예끼치 않게 만료되었습니다.",
    "Provided email-address is not valid" : "지정한 파일이 사진이 아님",
    "%s has published the calendar »%s«" : "%s 님이 달력 \"%s\"을(를) 공개했습니다",
    "Unexpected error sending email. Please contact your administrator." : "재설정 메일을 보낼 수 없습니다. 관리자에게 문의하십시오.",
    "Successfully sent email to " : "성공적으로 이메일을 보냈습니다. ",
    "Hello," : "안녕하세요,",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s 님이 달력 \"%s\"을(를) 공개했음을 알려 드립니다.",
    "Open »%s«" : "%s 열기",
    "Cheers!" : "감사합니다!",
    "Calendar" : "달력",
    "A Calendar app for Nextcloud" : "Nextcloud 달력 앱",
    "Previous day" : "이전날",
    "Previous week" : "이전주",
    "Previous month" : "이전달",
    "Next day" : "다음날",
    "Next week" : "다음주",
    "Next month" : "다음달",
    "Today" : "오늘",
    "Day" : "일",
    "Week" : "주",
    "Month" : "달",
    "Untitled calendar" : "제목없는 일정",
    "Edit name" : "이름 편집",
    "Edit color" : "색 편집",
    "Copy private link" : "개인 링크 주소 복사",
    "Download" : "다운로드",
    "Unshare from me" : "나의 공유 해제",
    "Delete" : "삭제",
    "An error occurred, unable to change visibility of the calendar." : "오류가 발생하여 일정의 공개 설정을 변경할 수 없습니다.",
    "An error occurred, unable to delete the calendar." : "오류가 발생하여 일정을 삭제할 수 없습니다.",
    "Calendar link copied to clipboard." : "일정의 링크를 클립보드에 복사되었습니다.",
    "Calendar link could not be copied to clipboard." : "일정의 링크를 클립보드에 저장할 수 없습니다.",
    "An error occurred, unable to rename the calendar." : "오류가 발생하여 일정의 이름은 변경할 수 없습니다.",
    "An error occurred, unable to change the calendar's color." : "오류가 발생하여 일정의 색깔을 변경할 수 없습니다.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown}초 후 일정 공유 해제"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["{countdown}초 후 일정 삭제"],
    "Share link" : "링크 공유",
    "Publish calendar" : "달력 게시",
    "Copy public link" : "공개 링크 복사",
    "Copy subscription link" : "구독 링크 복사",
    "Delete share link" : "공유 링크 삭제",
    "Share with users or groups" : "사용자 및 그룹과 공유",
    "No users or groups" : "사용자나 그룹 없음",
    "can edit" : "편집 가능",
    "New calendar" : "새 달력",
    "Filename" : "파일 이름",
    "Cancel" : "취소",
    "Automatic" : "자동",
    "Show week numbers" : "주 번호 보이기",
    "Settings & import" : "설정 및 가져오기",
    "Notification" : "알림",
    "Email" : "이메일",
    "Busy" : "바쁨",
    "Unknown" : "알 수 없음",
    "All day" : "하루 종일",
    "never" : "없음",
    "after" : "이후",
    "Repeat" : "반복",
    "Monday" : "월요일",
    "Summary" : "요약",
    "More" : "더 보기",
    "Save" : "저장",
    "Update" : "업데이트",
    "Select Date" : "날짜 선택",
    "Type to search timezone" : "시간대를 찾기 위해 입력하세요.",
    "Personal" : "개인",
    "Details" : "자세한 정보",
    "Attendees" : "참석자",
    "Reminders" : "알림",
    "Activity" : "활동",
    "Close" : "닫기",
    "Anniversary" : "기념일",
    "Week {number} of {year}" : "{year}년 제 {number}주",
    "Daily" : "매일",
    "Weekly" : "매주",
    "When shared show full event" : "전체 일정 공유",
    "When shared show only busy" : "바쁨/한가함만 공유",
    "When shared hide this event" : "일정 공유하지 않음",
    "Location" : "위치",
    "Description" : "설명",
    "Status" : "상태",
    "Confirmed" : "확인됨",
    "Tentative" : "예정됨",
    "Cancelled" : "취소됨",
    "Categories" : "분류",
    "Presentation" : "프레젠테이션",
    "Review" : "Review",
    "Mail" : "메일",
    "Play" : "재생",
    "Global" : "국제"
},
"nplurals=1; plural=0;");

==> nextcloud-app-calendar-1%3A2.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ko.js <==
OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "사용자 세션이 예끼치 않게 만료되었습니다.",
    "Provided email-address is not valid" : "지정한 파일이 사진이 아님",
    "%s has published the calendar »%s«" : "%s 님이 달력 \"%s\"을(를) 공개했습니다",
    "Unexpected error sending email. Please contact your administrator." : "재설정 메일을 보낼 수 없습니다. 관리자에게 문의하십시오.",
    "Successfully sent email to " : "성공적으로 이메일을 보냈습니다. ",
    "Hello," : "안녕하세요,",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s 님이 달력 \"%s\"을(를) 공개했음을 알려 드립니다.",
    "Open »%s«" : "%s 열기",
    "Cheers!" : "감사합니다!",
    "Calendar" : "달력",
    "A Calendar app for Nextcloud" : "Nextcloud 달력 앱",
    "Previous day" : "이전날",
    "Previous week" : "이전주",
    "Previous month" : "이전달",
    "Next day" : "다음날",
    "Next week" : "다음주",
    "Next month" : "다음달",
    "+ New event" : "+ 새 이벤트",
    "Today" : "오늘",
    "Day" : "일",
    "Week" : "주",
    "Month" : "달",
    "Untitled calendar" : "제목없는 일정",
    "Edit name" : "이름 편집",
    "Saving name …" : "이름 저장 중...",
    "Edit color" : "색 편집",
    "Saving color …" : "색깔 저장 중...",
    "Copy private link" : "개인 링크 주소 복사",
    "Download" : "다운로드",
    "Unshare from me" : "나의 공유 해제",
    "Delete" : "삭제",
    "An error occurred, unable to change visibility of the calendar." : "오류가 발생하여 일정의 공개 설정을 변경할 수 없습니다.",
    "An error occurred, unable to delete the calendar." : "오류가 발생하여 일정을 삭제할 수 없습니다.",
    "Calendar link copied to clipboard." : "일정의 링크를 클립보드에 복사되었습니다.",
    "Calendar link could not be copied to clipboard." : "일정의 링크를 클립보드에 저장할 수 없습니다.",
    "An error occurred, unable to rename the calendar." : "오류가 발생하여 일정의 이름은 변경할 수 없습니다.",
    "An error occurred, unable to change the calendar's color." : "오류가 발생하여 일정의 색깔을 변경할 수 없습니다.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown}초 후 일정 공유 해제"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["{countdown}초 후 일정 삭제"],
    "Share link" : "링크 공유",
    "Publish calendar" : "달력 게시",
    "Copy public link" : "공개 링크 복사",
    "Copy subscription link" : "구독 링크 복사",
    "Delete share link" : "공유 링크 삭제",
    "Share with users or groups" : "사용자 및 그룹과 공유",
    "No users or groups" : "사용자나 그룹 없음",
    "can edit" : "편집 가능",
    "New calendar" : "새 달력",
    "Filename" : "파일 이름",
    "Cancel" : "취소",
    "Automatic" : "자동",
    "Actions" : "동작",
    "Show week numbers" : "주 번호 보이기",
    "Settings & import" : "설정 및 가져오기",
    "Notification" : "알림",
    "Email" : "이메일",
    "Busy" : "바쁨",
    "Unknown" : "알 수 없음",
    "All day" : "하루 종일",
    "never" : "없음",
    "after" : "이후",
    "Repeat" : "반복",
    "Monday" : "월요일",
    "Summary" : "요약",
    "More" : "더 보기",
    "Save" : "저장",
    "Update" : "업데이트",
    "Type to search timezone" : "시간대를 찾기 위해 입력하세요.",
    "Personal" : "개인",
    "Details" : "자세한 정보",
    "Attendees" : "참석자",
    "Reminders" : "알림",
    "Activity" : "활동",
    "Projects" : "프로젝트",
    "Close" : "닫기",
    "Anniversary" : "기념일",
    "Week {number} of {year}" : "{year}년 제 {number}주",
    "Daily" : "매일",
    "Weekly" : "매주",
    "When shared show full event" : "전체 일정 공유",
    "When shared show only busy" : "바쁨/한가함만 공유",
    "When shared hide this event" : "일정 공유하지 않음",
    "Location" : "위치",
    "Description" : "설명",
    "Status" : "상태",
    "Confirmed" : "확인됨",
    "Tentative" : "예정됨",
    "Cancelled" : "취소됨",
    "Categories" : "분류",
    "Presentation" : "프레젠테이션",
    "Movie" : "영화",
    "Review" : "Review",
    "Mail" : "메일",
    "Play" : "재생",
    "Global" : "국제"
},
"nplurals=1; plural=0;");
